@@ -14,7 +14,7 @@ use MooX qw/late/;
 
 use PDL;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 has chosen_scans => (isa => 'ArrayRef', is => 'rw');
 has _iter_idx => (isa => 'Int', is => 'rw', default => sub { 0; },);
@@ -625,11 +625,12 @@ __END__
 
 =head1 NAME
 
-AI::Pathfinding::OptimizeMultiple
+AI::Pathfinding::OptimizeMultiple - optimize path finding searches for a large
+set of initial conditions (for better average performance).
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -702,6 +703,8 @@ across a representative number of initial cases, find a scan
 that solves most deals with close-to-optimal performance, by using switch
 tasking.
 
+=head1 SUBROUTINES/METHODS
+
 =head2 my $chosen_scans_array_ref = $self->chosen_scans()
 
 Returns the scans that have been chosen to perform the iteration. Each one is
@@ -755,27 +758,6 @@ Returns the total iterations count so far.
 
 Moo leftover. B<INTERNAL USE>.
 
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple - optimize path finding searches for a large
-set of initial conditions (for better average performance).
-
-=head1 VERSION
-
-Version 0.0.1
-
 =head1 SEE ALSO
 
 =over 4
