@@ -7,7 +7,7 @@ use MooX qw/late/;
 
 use PDL ();
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 use vars (qw(@fields));
 
@@ -172,35 +172,11 @@ __END__
 
 =head1 NAME
 
-AI::Pathfinding::OptimizeMultiple::IterState
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple::IterState
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple::IterState
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 NAME
-
 AI::Pathfinding::OptimizeMultiple::IterState - iteration state object.
 
 =head1 VERSION
 
-Version 0.0.1
+version 0.0.2
 
 =head1 SUBROUTINES/METHODS
 
