@@ -5,6 +5,8 @@ use warnings;
 
 use MooX qw/late/;
 
+our $VERSION = '0.0.2';
+
 has _should_do_rle => (isa => 'Bool', is => 'ro', init_arg => 'do_rle', required => 1);
 has _offset_quotas => (isa => 'Bool', is => 'ro', init_arg => 'offset_quotas', required => 1);
 
@@ -69,27 +71,11 @@ __END__
 
 =head1 NAME
 
-AI::Pathfinding::OptimizeMultiple::PostProcessor
-
-=head1 VERSION
-
-version 0.0.1
-
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple::PostProcessor
-
-=head1 NAME
-
-AI::Pathfinding::OptimizeMultiple::PostProcessor
-
-=head1 NAME
-
 AI::Pathfinding::OptimizeMultiple::PostProcessor - post-processor.
 
 =head1 VERSION
 
-Version 0.0.1
+version 0.0.2
 
 =head1 SUBROUTINES/METHODS
 
